@@ -9,10 +9,9 @@
  */
 
 #include <config.h>
+#include <portable/apr.h>
 #include <portable/system.h>
 
-#include <apr_pools.h>
-
 #include <lib/internal.h>
 #include <webauth/basic.h>
 #include <webauth/keys.h>
