@@ -38,8 +38,9 @@
 # include <com_err.h>
 #endif
 
-#include <lib/webauth.h>
 #include <util/macros.h>
+#include <webauth.h>
+#include <webauth/basic.h>
 
 typedef struct {
     krb5_context ctx;
@@ -264,7 +265,7 @@ verify_tgt(WEBAUTH_KRB5_CTXTP *c, const char *keytab_path,
 
 
 /*
- * Given a portion of a Kerberos v5 principal and its length, allocate a new
+ * Given a portion of a Kerberos principal and its length, allocate a new
  * string and write the escaped form of that portion of a principal to the
  * newly allocated string.  Returns the newly allocated string, which the
  * caller is responsible for freeing, or NULL on failure.
@@ -356,7 +357,7 @@ webauth_krb5_new(WEBAUTH_KRB5_CTXT **ctxt)
 
 
 /*
- * Return the Kerberos v5 error code from the last operation.
+ * Return the Kerberos error code from the last operation.
  */
 int
 webauth_krb5_error_code(WEBAUTH_KRB5_CTXT *context)
@@ -368,7 +369,7 @@ webauth_krb5_error_code(WEBAUTH_KRB5_CTXT *context)
 
 
 /*
- * Return the Kerberos v5 error message from the last operation, using com_err
+ * Return the Kerberos error message from the last operation, using com_err
  * to map the code to a message.
  */
 const char *
@@ -621,8 +622,7 @@ webauth_krb5_keep_cred_cache(WEBAUTH_KRB5_CTXT *context)
 
 
 /*
- * Free a Kerberos v5 context and the associated data.  Returns a WA_ERR
- * code.
+ * Free a Kerberos context and the associated data.  Returns a WA_ERR code.
  */
 int
 webauth_krb5_free(WEBAUTH_KRB5_CTXT *context)
@@ -765,7 +765,7 @@ webauth_krb5_init_via_keytab(WEBAUTH_KRB5_CTXT *context,
  * Initialize a context via a passed, delegated credential.
  */
 int
-webauth_krb5_init_via_cred(WEBAUTH_KRB5_CTXT *context, char *cred,
+webauth_krb5_init_via_cred(WEBAUTH_KRB5_CTXT *context, const void *cred,
                            size_t cred_len, const char *cache_name)
 {
     WEBAUTH_KRB5_CTXTP *c = (WEBAUTH_KRB5_CTXTP *) context;
@@ -812,7 +812,7 @@ webauth_krb5_init_via_cred(WEBAUTH_KRB5_CTXT *context, char *cred,
  * Import a credential into an existing ticket cache.
  */
 int
-webauth_krb5_import_cred(WEBAUTH_KRB5_CTXT *context, char *cred,
+webauth_krb5_import_cred(WEBAUTH_KRB5_CTXT *context, const char *cred,
                          size_t cred_len)
 {
     WEBAUTH_KRB5_CTXTP *c = (WEBAUTH_KRB5_CTXTP *) context;
@@ -939,3 +939,34 @@ webauth_krb5_get_realm(WEBAUTH_KRB5_CTXT *context, char **realm)
     *realm = escape_principal(raw, length);
     return (*realm == NULL) ? WA_ERR_NO_MEM : WA_ERR_NONE;
 }
+
+
+/*
+ * Get the ticket cache from the context.  Stores the newly allocated string
+ * in cache and returns WA_ERR_NONE on success, or another error code on
+ * failure.
+ */
+int
+webauth_krb5_get_cache(WEBAUTH_KRB5_CTXT *context, char **cache)
+{
+    WEBAUTH_KRB5_CTXTP *c = (WEBAUTH_KRB5_CTXTP *) context;
+    const char *type, *name;
+    size_t length;
+
+    if (c->cc == NULL)
+        return WA_ERR_INVALID_CONTEXT;
+    type = krb5_cc_get_type(c->ctx, c->cc);
+    if (type == NULL)
+        return WA_ERR_KRB5;
+    name = krb5_cc_get_name(c->ctx, c->cc);
+    if (name == NULL)
+        return WA_ERR_KRB5;
+    length = strlen(type) + 1 + strlen(name) + 1;
+    *cache = malloc(length);
+    if (*cache == NULL)
+        return WA_ERR_NO_MEM;
+    strlcpy(*cache, type, length);
+    strlcat(*cache, ":", length);
+    strlcat(*cache, name, length);
+    return WA_ERR_NONE;
+}
