@@ -13,11 +13,9 @@
  */
 
 #include <config.h>
+#include <portable/apr.h>
 #include <portable/system.h>
 
-#include <apr_pools.h>
-#include <apr_strings.h>
-#include <apr_tables.h>
 #include <time.h>
 
 #include <tests/tap/basic.h>
